detect_memory_availability

Function detect_memory_availability 

pub fn detect_memory_availability() -> MemoryAvailability
Refresh and return the OS and cgroup observations that govern process memory admission. This is the single system-memory authority shared by the global governor and specialized runtime planners.